#[non_exhaustive]pub enum AvatarCompatibilityMode {
Strict,
LegacyV1,
}Expand description
Style compatibility policy used while preparing an avatar request.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Strict
Reject explicit style layers that the selected family cannot render.
LegacyV1
Preserve the Hashavatar 1.x behavior of ignoring unsupported layers.